/*
 * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002
 *	Tama Communications Corporation
 *
 * This file is part of GNU GLOBAL.
 *
 * GNU GLOBAL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * GNU GLOBAL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#ifndef _GLOBAL_H_
#define _GLOBAL_H_

#include "gparam.h"
#include "abs2rel.h"
#include "char.h"
#include "conf.h"
#include "date.h"
#include "dbop.h"
#include "defined.h"
#include "die.h"
#include "env.h"
#include "find.h"
#include "format.h"
#include "getdbpath.h"
#include "gtagsop.h"
#include "idset.h"
#include "is_unixy.h"
#include "langmap.h"
#include "linetable.h"
#include "locatestring.h"
#include "makepath.h"
#include "path.h"
#include "pathconvert.h"
#include "gpathop.h"
#include "split.h"
#include "strbuf.h"
#include "strhash.h"
#include "strlimcpy.h"
#include "strmake.h"
#include "tab.h"
#include "tagsort.h"
#include "test.h"
#include "token.h"
#include "usable.h"
#include "version.h"
#include "varray.h"
#include "xargs.h"

#endif /* ! _GLOBAL_H_ */
